import React from 'react';
import type { PropsWithMetadata } from '@highlight-ui/utils-commons';
import type { TooltipProps } from '@highlight-ui/tooltip';
export declare type ToggleInputBaseProps = Omit<React.ComponentPropsWithoutRef<'input'>, 'children'> & PropsWithMetadata<{
    /** Text that will be displayed next to the input */
    label?: string;
    /** Grayed-out piece of text that will be displayed below the label */
    subLabel?: string;
    /** The content of the tooltip pop-out. When supplied, a tooltip will be placed next to the label. */
    tooltipContent?: TooltipProps['content'];
    /** Specifies how to to keep the tooltip opened after the mouse has left the tooltip icon */
    tooltipMouseOutDelay?: TooltipProps['mouseOutDelay'];
    /** Sets the tone of the input. ex: error */
    tone?: 'error' | 'default';
}>;
export declare type ToggleInputProps = Omit<React.ComponentPropsWithoutRef<'input'>, 'children' | 'className' | 'id'> & PropsWithMetadata<{
    /** The input id. */
    id: React.HTMLAttributes<'input'>['id'];
}>;
export declare type ToggleInputLabelProps = Pick<ToggleInputBaseProps, 'metadata' | 'label' | 'tooltipContent' | 'tooltipMouseOutDelay' | 'tone' | 'disabled'> & {
    /** The input id that is linked to this label */
    inputId: string;
    /** The ToggleInput selection icon */
    icon?: React.SVGProps<SVGElement>;
};
export declare type ToggleInputSubLabelProps = Pick<ToggleInputBaseProps, 'metadata' | 'disabled'> & PropsWithMetadata<{
    /** The input id that is linked to this hint text */
    inputId: string;
    /** Grayed-out piece of text that will be displayed below the label */
    subLabel: string;
    /** Whether the input is in a disabled state */
    disabled?: boolean;
}>;
export declare type ToggleInputGroupProps = PropsWithMetadata<{
    /** Applies a class name to the root element */
    className?: string;
    /** The name to apply to every ToggleInput in the group. A name is generated if none is specified */
    name?: string;
    /** Disables every ToggleInput in the group */
    disabled?: boolean;
    /** Sets the orientation of the ToggleInput group */
    orientation?: 'vertical' | 'horizontal';
}>;
